VPSPulse Mirrors

High-Performance Open-Source Archive

Help for package BEACH

Package {BEACH}


Type: Package
Title: Biometric Exploratory Analysis Creation House
Version: 1.3.2
Description: A platform for interactive data analysis designed to simplify development, deployment, interaction, and exploration (TEDDIE). The package enables users to create customized analyses and deploy them to end users, who can perform interactive analyses and export results to RTF or HTML files. It allows developers to focus on R code for analysis rather than managing HTML or Shiny application code.
Depends: R (≥ 3.1.0)
Imports: shiny, DT, haven, xtable, plyr, WriteXLS
License: MIT + file LICENSE
Encoding: UTF-8
URL: https://pharmasug.org/proceedings/2018/AD/PharmaSUG-2018-AD05.pdf, https://higherlogicdownload.s3.amazonaws.com/AMSTAT/fa4dd52c-8429-41d0-abdf-0011047bfa19/UploadedImages/Webinars/2017/2017-09_Yu.pdf
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2026-05-05 06:38:22 UTC; dyu
Author: Danni Yu [aut, cre], Michael Man [aut], ChenChen Yu [ctb]
Maintainer: Danni Yu <danni.yu@gmail.com>
Repository: CRAN
Date/Publication: 2026-05-05 07:00:02 UTC

Need mirroring services?
Contact our team at info@vpspulse.com.

Mirror powered by VPSpulse

Infrastructure sponsored by VPSPulse & Secure Payments by ArionPay.