Package 'BEACH'
| Title: |
Biometric Exploratory Analysis Creation House |
| Description: |
A platform for interactive data analysis designed to
simplify development, deployment, interaction, and exploration
(TEDDIE). The package enables users to create customized
analyses and deploy them to end users, who can perform
interactive analyses and export results to RTF or HTML files.
It allows developers to focus on R code for analysis rather
than managing HTML or Shiny application code. |
| Authors: |
Danni Yu [aut, cre], Michael Man [aut], ChenChen Yu [ctb] |
| Maintainer: |
Danni Yu <[email protected]> |
| License: |
MIT + file LICENSE |
| Version: |
1.3.2 |
| Built: |
2026-06-04 06:54:51 UTC |
| Source: |
https://github.com/cran/BEACH |
Help Index